@@ -92,30 +92,30 @@ __all__ = [
 
 
 def __getattr__(name: str) -> str:
+    import warnings
+
+    from importlib.metadata import metadata, version
+
     dunder_to_metadata = {
-        "__version__": "version",
         "__description__": "summary",
         "__uri__": "",
         "__email__": "",
+        "__version__": "",
     }
-    if name not in dunder_to_metadata.keys():
-        raise AttributeError(f"module {__name__} has no attribute {name}")
+    if name not in dunder_to_metadata:
+        msg = f"module {__name__} has no attribute {name}"
+        raise AttributeError(msg)
 
-    import sys
-    import warnings
-
-    if sys.version_info < (3, 8):
-        from importlib_metadata import metadata
+    if name != "__version__":
+        warnings.warn(
+            f"Accessing structlog.{name} is deprecated and will be "
+            "removed in a future release. Use importlib.metadata directly "
+            "to query for structlog's packaging metadata.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
     else:
-        from importlib.metadata import metadata
-
-    warnings.warn(
-        f"Accessing structlog.{name} is deprecated and will be "
-        "removed in a future release. Use importlib.metadata directly "
-        "to query for structlog's packaging metadata.",
-        DeprecationWarning,
-        stacklevel=2,
-    )
+        return version("structlog")
 
     meta = metadata("structlog")
 
