@@ -11,7 +11,7 @@ import traceback
 from io import StringIO
 from types import FrameType
 
-from .types import ExcInfo
+from .typing import ExcInfo
 
 
 def _format_exception(exc_info: ExcInfo) -> str:
@@ -20,6 +20,9 @@ def _format_exception(exc_info: ExcInfo) -> str:
 
     Shamelessly stolen from stdlib's logging module.
     """
+    if exc_info == (None, None, None):  # type: ignore[comparison-overlap]
+        return "MISSING"
+
     sio = StringIO()
 
     traceback.print_exception(exc_info[0], exc_info[1], exc_info[2], None, sio)
@@ -37,10 +40,14 @@ def _find_first_app_frame_and_name(
     """
     Remove all intra-structlog calls and return the relevant app frame.
 
-    :param additional_ignores: Additional names with which the first frame must
-        not start.
+    Arguments:
 
-    :returns: tuple of (frame, name)
+        additional_ignores:
+            Additional names with which the first frame must not start.
+
+    Returns:
+
+        tuple of (frame, name)
     """
     ignores = ["structlog"] + (additional_ignores or [])
     f = sys._getframe()
