@@ -24,7 +24,7 @@ from typing import Any, Generator, Mapping
 
 import structlog
 
-from .types import BindableLogger, EventDict, WrappedLogger
+from .typing import BindableLogger, EventDict, WrappedLogger
 
 
 STRUCTLOG_KEY_PREFIX = "structlog_"
@@ -38,7 +38,7 @@ _CONTEXT_VARS: dict[str, contextvars.ContextVar[Any]] = {}
 
 def get_contextvars() -> dict[str, Any]:
     """
-    Return a copy of the ``structlog``-specific context-local context.
+    Return a copy of the *structlog*-specific context-local context.
 
     .. versionadded:: 21.2.0
     """
